==> Smdn.Formats.Mime-0.15.tar.bz2: Smdn.Formats.Mime-0.15/Smdn.Formats.Mime/Smdn.Formats.Mime/MimeHeaderParameterFragment.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2009 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Text;

namespace Smdn.Formats.Mime {
  public class MimeHeaderParameterFragment : MimeHeaderFragment {
    public MimeHeaderParameterFragment(string @value)
      : base(@value)
    {
    }

    public MimeHeaderParameterFragment(string @value, MimeHeaderEncoding encoding, Encoding charset)
      : base(@value, encoding, charset)
    {
    }

    public MimeHeaderParameterFragment(string name, string @value)
      : base(Join(name, @value))
    {
    }

    public MimeHeaderParameterFragment(string name, string @value, MimeHeaderEncoding encoding, Encoding charset)
      : base(Join(name, @value), encoding, charset)
    {
    }

    private static string Join(string name, string @value)
    {
      if (name == null)
        throw new ArgumentNullException("name");
      if (@value == null)
        throw new ArgumentNullException("value");

      return string.Format("{0}=\"{1}\"", name, @value);
    }
  }
}

==> Smdn.Formats.Mime-0.20.tar.bz2: Smdn.Formats.Mime-0.20/Smdn.Formats.Mime/Smdn.Formats.Mime/MimeHeaderParameterFragment.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Text;

namespace Smdn.Formats.Mime {
  public class MimeHeaderParameterFragment : MimeHeaderFragment {
    public MimeHeaderParameterFragment(string @value)
      : base(@value)
    {
    }

    public MimeHeaderParameterFragment(string @value, MimeEncodingMethod encoding, Encoding charset)
      : base(@value, encoding, charset)
    {
    }

    public MimeHeaderParameterFragment(string name, string @value)
      : base(Join(name, @value))
    {
    }

    public MimeHeaderParameterFragment(string name, string @value, MimeEncodingMethod encoding, Encoding charset)
      : base(Join(name, @value), encoding, charset)
    {
    }

    private static string Join(string name, string @value)
    {
      if (name == null)
        throw new ArgumentNullException("name");
      if (@value == null)
        throw new ArgumentNullException("value");

      return string.Format("{0}=\"{1}\"", name, @value);
    }
  }
}
